@charset "UTF-8";
div.phpdebugbar-widgets-sqlqueries .phpdebugbar-widgets-status {
  color: #555;
  background: #fafafa;
  border-bottom: 1px solid #ddd;
  padding: 6px;
  font-family: SFMono-Regular, Consolas, Liberation Mono, Menlo, Courier, monospace;
  font-weight: bold;
}

div.phpdebugbar-widgets-sqlqueries li.phpdebugbar-widgets-list-item.phpdebugbar-widgets-error {
  color: red;
}

div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-database, div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-duration, div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-memory, div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-row-count, div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-copy-clipboard, div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-eye, div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-eye-dash, div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-stmt-id {
  float: right;
  color: #888;
  margin-left: 8px;
}

div.phpdebugbar-widgets-sqlqueries a.phpdebugbar-widgets-editor-link {
  float: right;
  margin-left: 8px;
}

div.phpdebugbar-widgets-sqlqueries div.phpdebugbar-widgets-status span.phpdebugbar-widgets-database, div.phpdebugbar-widgets-sqlqueries div.phpdebugbar-widgets-status span.phpdebugbar-widgets-duration, div.phpdebugbar-widgets-sqlqueries div.phpdebugbar-widgets-status span.phpdebugbar-widgets-memory, div.phpdebugbar-widgets-sqlqueries div.phpdebugbar-widgets-status span.phpdebugbar-widgets-row-count, div.phpdebugbar-widgets-sqlqueries div.phpdebugbar-widgets-status span.phpdebugbar-widgets-copy-clipboard, div.phpdebugbar-widgets-sqlqueries div.phpdebugbar-widgets-status span.phpdebugbar-widgets-eye, div.phpdebugbar-widgets-sqlqueries div.phpdebugbar-widgets-status span.phpdebugbar-widgets-eye-dash, div.phpdebugbar-widgets-sqlqueries div.phpdebugbar-widgets-status span.phpdebugbar-widgets-stmt-id {
  color: #555;
}

div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-database:before, div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-duration:before, div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-memory:before, div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-row-count:before, div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-copy-clipboard:before, div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-eye:before, div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-eye-dash:before, div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-stmt-id:before, div.phpdebugbar-widgets-sqlqueries a.phpdebugbar-widgets-editor-link:before {
  margin-right: 4px;
  font-family: "Font Awesome 6 Free";
  font-size: 12px;
  font-weight: 900;
}

div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-database:before {
  content: "";
}

div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-duration:before {
  content: "";
}

div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-memory:before {
  content: "";
}

div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-row-count:before {
  content: "";
}

div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-stmt-id:before {
  content: "";
}

div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-copy-clipboard:before {
  content: "";
}

div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-eye:before {
  content: "";
}

div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-eye-dash:before {
  content: "";
}

div.phpdebugbar-widgets-sqlqueries a.phpdebugbar-widgets-editor-link:before {
  content: "";
  margin-left: 4px;
}

div.phpdebugbar-widgets-sqlqueries span.phpdebugbar-widgets-eye-dash {
  background-color: #eee;
  padding: 2px;
}

div.phpdebugbar-widgets-sqlqueries table.phpdebugbar-widgets-params {
  border-collapse: collapse;
  border: 1px solid #ddd;
  width: 70%;
  margin: 10px 0;
  font-family: SFMono-Regular, Consolas, Liberation Mono, Menlo, Courier, monospace;
  display: none;
}

div.phpdebugbar-widgets-sqlqueries table.phpdebugbar-widgets-params td, div.phpdebugbar-widgets-sqlqueries table.phpdebugbar-widgets-explain td {
  border: 1px solid #ddd;
  padding: 3px;
}

div.phpdebugbar-widgets-sqlqueries table.phpdebugbar-widgets-params .phpdebugbar-widgets-name {
  width: 20%;
  font-weight: bold;
}

div.phpdebugbar-widgets-sqlqueries table.phpdebugbar-widgets-callstack, div.phpdebugbar-widgets-sqlqueries table.phpdebugbar-widgets-explain {
  border-collapse: collapse;
  border: 1px solid #ddd;
  width: 100%;
  margin: 10px 0;
  font-family: SFMono-Regular, Consolas, Liberation Mono, Menlo, Courier, monospace;
  display: none;
}

div.phpdebugbar-widgets-sqlqueries table.phpdebugbar-widgets-callstack tr.caller {
  background-color: #fff9b6;
}

div.phpdebugbar-widgets-sqlqueries table.phpdebugbar-widgets-callstack tbody tr:hover {
  background-color: #eee;
}

div.phpdebugbar-widgets-sqlqueries table.phpdebugbar-widgets-callstack th, div.phpdebugbar-widgets-sqlqueries table.phpdebugbar-widgets-explain th, div.phpdebugbar-widgets-sqlqueries table.phpdebugbar-widgets-params th {
  padding: 3px;
  font-weight: bold;
}

div.phpdebugbar-widgets-sqlqueries li.phpdebugbar-widgets-list-item {
  border-bottom: 1px solid #00f;
  padding: 10px 6px;
}

div.phpdebugbar-widgets-sqlqueries li.phpdebugbar-widgets-list-item span.phpdebugbar-widgets-error {
  font-weight: bold;
  display: block;
}

code.phpdebugbar-widgets-sql {
  word-wrap: break-word;
  overflow-wrap: break-word;
  white-space: pre-wrap;
}

div.phpdebugbar-widgets-sqlqueries li.phpdebugbar-widgets-list-item.phpdebugbar-widgets-sql-duplicate {
  background-color: #edeff0;
}

div.phpdebugbar-widgets-sqlqueries li.phpdebugbar-widgets-list-item.phpdebugbar-widgets-sql-duplicate:hover {
  background-color: #ffc;
}

div.phpdebugbar-widgets-sqlqueries div.phpdebugbar-widgets-toolbar {
  z-index: 1;
  background: #fff;
  width: 100%;
  display: none;
  position: fixed;
  bottom: 0;
}

div.phpdebugbar-widgets-sqlqueries div.phpdebugbar-widgets-toolbar a.phpdebugbar-widgets-filter {
  float: right;
  color: #fff;
  background: #7cacd5;
  border-radius: 4px;
  margin: 0 2px;
  padding: 2px 4px;
  font-size: 12px;
  text-decoration: none;
}

div.phpdebugbar-widgets-sqlqueries div.phpdebugbar-widgets-toolbar a.phpdebugbar-widgets-filter.phpdebugbar-widgets-excluded {
  color: #888;
  background: #eee;
}

div.phpdebugbar[data-theme="dark"] div.phpdebugbar-widgets-sqlqueries li.phpdebugbar-widgets-list-item.phpdebugbar-widgets-sql-duplicate {
  background-color: #473e00;
}
